]> mj.ucw.cz Git - pciutils.git/commitdiff
Spelling fixes.
authorMartin Mares <mj@ucw.cz>
Tue, 23 Aug 2005 18:33:44 +0000 (18:33 +0000)
committerMartin Mares <mj@ucw.cz>
Fri, 5 May 2006 12:18:27 +0000 (14:18 +0200)
git-archimport-id: mj@ucw.cz--public/pciutils--main--2.2--patch-72

ChangeLog
README
TODO
lspci.c
setpci.man

index 27bc5c4c5f6ae88858afe7ebcfa5f13c73499ad7..93f7520f6aa5e2b9473f521564bd9323cf426746 100644 (file)
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,7 @@
 2005-08-23  Martin Mares  <mj@ucw.cz>
 
+       * setpci.man, lspci.c, README: prefer spelling "buses" over "busses".
+
        * lspci.c: If alloca() is not available, use xmalloc(), not malloc().
 
        * lib/configure: Added x86_64 on Linux.
diff --git a/README b/README
index 26bfa58601b45df84caf402a885cf3fc78da9fca..e47ddfc97d02ef3bc6e1cc6b987f253d79248242 100644 (file)
--- a/README
+++ b/README
@@ -35,7 +35,7 @@ include them in the next version).
 
 The utilities include:  (See manual pages for more details)
 
-  - lspci: displays detailed information about all PCI busses and devices.
+  - lspci: displays detailed information about all PCI buses and devices.
 
   - setpci: allows to read from and write to PCI device configuration
     registers. For example, you can adjust the latency timers with it.
diff --git a/TODO b/TODO
index 158602c1ac99f3f12b913fe980686f9d1be31823..ff4a1992c15e80d9c7c200eda5c4628dd227ec16 100644 (file)
--- a/TODO
+++ b/TODO
@@ -1,12 +1,8 @@
 - lspci: don't die when non-root tries to dump cardbus data; mention the
   "available only to root" things in the man page. And possibly adjust exit code.
 
-- pci.ids: "Unknown mass storage controller" -> "Mass storage controller".
-
 - names.c: rewrite
 
-- spelling: buses x busses
-
 - update the web page
 
 - unused parameter warnings
diff --git a/lspci.c b/lspci.c
index e811b9e525d934ab4ef848da481b6d6455835ec1..c6c4dfbff1ba99873f216bb9767f28dc7bbf4332 100644 (file)
--- a/lspci.c
+++ b/lspci.c
@@ -1806,7 +1806,7 @@ show(void)
 struct bridge {
   struct bridge *chain;                        /* Single-linked list of bridges */
   struct bridge *next, *child;         /* Tree of bridges */
-  struct bus *first_bus;               /* List of busses connected to this bridge */
+  struct bus *first_bus;               /* List of buses connected to this bridge */
   unsigned int domain;
   unsigned int primary, secondary, subordinate;        /* Bus numbers */
   struct device *br_dev;
index 5dda2480c96bf7b3eb5d2b0807a659ea2ede8846..6eb2bde8bf03429e595738f8863619182d3fcad8 100644 (file)
@@ -197,7 +197,7 @@ Increase debug level of the library. (All systems)
 .PP
 `setpci -d *:* latency_timer=40' sets the latency timer to 64 (40 hexadecimal).
 .PP
-`setpci -s 0 device_id vendor_id' lists ID's of devices in slot 0 in all busses.
+`setpci -s 0 device_id vendor_id' lists ID's of devices in slot 0 in all buses.
 .PP
 `setpci -s 12:3.4 3c.l=1,2,3' writes longword 1 to register 3c, 2 to register 3d
 and 3 to register 3e of device at bus 12, slot 3, function 4.